@@ -1,9 +1,11 @@
 package Sidef::Types::Glob::Dir {
 
     use utf8;
-    use 5.014;
+    use 5.016;
 
-    use parent qw(Sidef::Types::Glob::File);
+    use parent qw(
+      Sidef::Types::Glob::File
+      );
 
     require File::Spec;
 
@@ -141,7 +143,7 @@ package Sidef::Types::Glob::Dir {
               };
         }
 
-        $success ? $dir_obj : ();
+        $success ? $dir_obj : undef;
     }
 
     *open_r = \&open;
