@@ -437,7 +437,29 @@ package Sidef::Types::Set::Bag {
         bless \%new, ref($self);
     }
 
-    *map_2D = \&map_2d;
+    sub map_kv {
+        my ($self, $block) = @_;
+
+        $block //= Sidef::Types::Block::Block::LIST_IDENTITY;
+
+        my %new;
+        foreach my $key (CORE::keys(%$self)) {
+
+            my $elem  = $self->{$key};
+            my @pairs = $block->run($elem->{value}, Sidef::Types::Number::Number->_set_uint($elem->{count}));
+
+            while (@pairs) {
+                my $k = shift(@pairs);
+                my $v = CORE::int(shift(@pairs));
+
+                if ($v > 0) {
+                    $new{$serialize->($k)} = {value => $k, count => $v};
+                }
+            }
+        }
+
+        bless \%new, ref($self);
+    }
 
     sub collect {
         my ($self, $block) = @_;
@@ -477,8 +499,6 @@ package Sidef::Types::Set::Bag {
     sub grep_2d {
         my ($self, $block) = @_;
 
-        $block //= Sidef::Types::Block::Block::ARRAY_IDENTITY;
-
         my %new;
         foreach my $key (CORE::keys(%$self)) {
 
@@ -496,7 +516,25 @@ package Sidef::Types::Set::Bag {
         bless \%new, ref($self);
     }
 
-    *grep_2D = \&grep_2d;
+    sub grep_kv {
+        my ($self, $block) = @_;
+
+        my %new;
+        foreach my $key (CORE::keys(%$self)) {
+
+            my $elem  = $self->{$key};
+            my $value = $elem->{value};
+
+            if ($block->run($value, Sidef::Types::Number::Number->_set_uint($elem->{count}))) {
+                $new{$key} = {
+                              value => $value,
+                              count => $elem->{count},
+                             };
+            }
+        }
+
+        bless \%new, ref($self);
+    }
 
     sub count_by {
         my ($self, $block) = @_;
@@ -643,8 +681,6 @@ package Sidef::Types::Set::Bag {
         $self;
     }
 
-    *each_2D = \&each_2d;
-
     sub each_kv {
         my ($self, $block) = @_;
 
