@@ -174,8 +174,6 @@ package Sidef::Types::Set::Set {
         bless \%new, ref($self);
     }
 
-    *map_2D = \&map_2d;
-
     sub collect {
         my ($self, $block) = @_;
 
@@ -208,8 +206,6 @@ package Sidef::Types::Set::Set {
     sub grep_2d {
         my ($self, $block) = @_;
 
-        $block //= Sidef::Types::Block::Block::ARRAY_IDENTITY;
-
         my %new;
         foreach my $key (CORE::keys(%$self)) {
             my $value = $self->{$key};
@@ -221,8 +217,6 @@ package Sidef::Types::Set::Set {
         bless \%new, ref($self);
     }
 
-    *grep_2D = \&grep_2d;
-
     sub count_by {
         my ($self, $block) = @_;
 
@@ -308,8 +302,6 @@ package Sidef::Types::Set::Set {
         $self;
     }
 
-    *each_2D = \&each_2d;
-
     sub sort_by {
         my ($self, $block) = @_;
         $self->values->sort_by($block);
@@ -340,6 +332,30 @@ package Sidef::Types::Set::Set {
         $self->values->min_by($block);
     }
 
+    sub sum {
+        my ($self, $block) = @_;
+        $self->to_a->sum($block);
+    }
+
+    *sum_by = \&sum;
+
+    sub prod {
+        my ($self, $block) = @_;
+        $self->to_a->prod($block);
+    }
+
+    *prod_by = \&prod;
+
+    sub sum_2d {
+        my ($self, $block) = @_;
+        $self->to_a->sum_2d($block);
+    }
+
+    sub prod_2d {
+        my ($self, $block) = @_;
+        $self->to_a->prod_2d($block);
+    }
+
     sub has {
         my ($self, $obj) = @_;
         my $key = $serialize->($obj);
